import textwrap
import yaml

from sphinxcontrib.openapi import renderers


class TestOpenApi3HttpDomain(object):

    def test_basic(self):
        spec = yaml.safe_load(textwrap.dedent("""
        ---
        openapi: 3.0.0
        info:
          description: >-
            This is a _text_.
        paths:
          /resources:
            get:
              description: test service
              responses:
                200:
                  description: Success
        """))

        renderer = renderers.DescriptionRenderer(None, {})
        text = '\n'.join(renderer.render_restructuredtext_markup(spec))

        assert text == "This is a _text_.\n"

        renderer = renderers.DescriptionRenderer(None, {"format": "markdown"})
        text = '\n'.join(renderer.render_restructuredtext_markup(spec))

        assert text == "\nThis is a *text*.\n"




from . import abc
from .. import utils


class DescriptionRenderer(abc.RestructuredTextRenderer):

    option_spec = {
        # Markup format to render OpenAPI descriptions.
        "format": str,
    }

    def __init__(self, state, options):
        self._state = state
        self._options = options

    def render_restructuredtext_markup(self, spec):

        utils.normalize_spec(spec, **self._options)

        convert = utils.get_text_converter(self._options)
        if 'info' in spec:
            if 'description' in spec['info']:
                for line in convert(spec['info']['description']).splitlines():
                    yield '{line}'.format(**locals())
                yield ''
